@@ -22,7 +22,8 @@ from quocslib.utils.AbstractFoM import AbstractFoM
 
 
 class Optimizer:
-    def __init__(self, optimization_dict: dict = None, FoM_object: AbstractFoM = None):
+    def __init__(self, optimization_dict: dict = None, FoM_object: AbstractFoM = None,
+                 comm_signals_list: [list, list, list] = None):
         """
         Write this docstring
         """
@@ -30,7 +31,8 @@ class Optimizer:
         self.communication_obj = AllInOneCommunication(interface_job_name=self.interface_job_name,
                                                        FoM_obj=FoM_object,
                                                        handle_exit_obj=HandleExit(),
-                                                       dump_attribute=BestDump)
+                                                       dump_attribute=BestDump,
+                                                       comm_signals_list=comm_signals_list)
 
         self.results_path = self.communication_obj.results_path
 
