@@ -15,6 +15,7 @@
 # ++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++
 import numpy as np
 from datetime import datetime
+import logging
 
 np.seterr(all="raise")
 
@@ -26,8 +27,7 @@ from quocslib.stoppingcriteria.NelderMeadStoppingCriteria import (
 class NelderMead(DirectSearchMethod):
     callback: callable
 
-    def __init__(self, settings: dict, stopping_criteria: dict, callback: callable = None,
-                 stop_optimization_callback: callable = None):
+    def __init__(self, settings: dict, stopping_criteria: dict, callback: callable = None):
         """
         Nelder-Mead is an updating algorithm based on the simplex method.
         :param dict settings: settings for the NM algorithm
@@ -40,10 +40,9 @@ class NelderMead(DirectSearchMethod):
         self.is_adaptive = settings.setdefault("is_adaptive", False)
         # TODO Create it using dynamical import module
         # Stopping criteria object
-        stopping_criteria.setdefault("stop_function", stop_optimization_callback)
         self.sc_obj = NelderMeadStoppingCriteria(stopping_criteria)
 
-    def run_dsm(self, func, x0, args=(), initial_simplex=None, max_eval_total=None,
+    def run_dsm(self, func, x0, args=(), initial_simplex=None,
                 drift_comp_minutes=0.0, **kwargs) -> dict:
         """
 
@@ -51,15 +50,13 @@ class NelderMead(DirectSearchMethod):
         :param np.array x0: initial point
         :param tuple args: Further arguments
         :param np.array initial_simplex: Starting simplex for the Nelder Mead evaluation
-        :param int max_eval_total: Maximum iteration number of function evaluations in total
+        :param float drift_comp_minutes: Compensate for drift after this number of minutes
         :return:
         """
         # Creation of the communication function for the OptimizationAlgorithm object
         calls_number, func = self._get_wrapper(args, func)
         # Set to false is_converged
         self.sc_obj.is_converged = False
-        # update the total max of function evaluations
-        self.sc_obj.max_eval_total = max_eval_total
         # Initialize the iteration number
         iterations = 0
         # Landscape dimension
@@ -160,10 +157,10 @@ class NelderMead(DirectSearchMethod):
                     prev_FoM = fsim[0]
                     fsim[0] = func(sim[0], iterations)
                     new_FoM = fsim[0]
-                    # ToDo: How do I print to the log from here?
                     message = f"Previous best FoM: {prev_FoM}, Current best FoM after drift " \
                               f"compensation (after {drift_comp_minutes} minutes): {new_FoM}"
-                    print(message)
+                    logger = logging.getLogger("oc_logger")
+                    logger.info(message)
             # Increase the NM iteration
             iterations += 1
             # Update function evaluations number
@@ -172,7 +169,8 @@ class NelderMead(DirectSearchMethod):
             if self.callback is not None:
                 if not self.callback():
                     self.sc_obj.is_converged = True
-                    self.sc_obj.terminate_reason = "User stopped the optimization"
+                    self.sc_obj.terminate_reason = "User stopped the optimization or higher order " \
+                                                   "stopping criterion has been reached"
             # Check stopping criteria
             self.sc_obj.check_stopping_criteria(sim, fsim, calls_number[0])
         # END of while loop
